==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPinColumnCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinColumnCancellableEventArgsDetailDescriptionMetadata } from "./WebPinColumnCancellableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDescription } from "./WebPinColumnCancellableEventArgsDescription";
/**
 * @hidden
 */
var WebPinColumnCancellableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPinColumnCancellableEventArgsDescriptionMetadata, _super);
    function WebPinColumnCancellableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnCancellableEventArgsDescriptionMetadata.b = function (a) {
        if (WebPinColumnCancellableEventArgsDescriptionMetadata.a == null) {
            WebPinColumnCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnCancellableEventArgsDescriptionMetadata.c(WebPinColumnCancellableEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebPinColumnCancellableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPinColumnCancellableEventArgsDescriptionMetadata.a);
        WebPinColumnCancellableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPinColumnCancellableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebPinColumnCancellableEventArgsDetail");
    };
    WebPinColumnCancellableEventArgsDescriptionMetadata.d = function (a) {
        WebPinColumnCancellableEventArgsDescriptionMetadata.b(a);
        a.aa("WebPinColumnCancellableEventArgs", function () { return new WebPinColumnCancellableEventArgsDescription(); });
        a.z("WebPinColumnCancellableEventArgs", WebPinColumnCancellableEventArgsDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDescriptionMetadata.$t = markType(WebPinColumnCancellableEventArgsDescriptionMetadata, 'WebPinColumnCancellableEventArgsDescriptionMetadata');
    WebPinColumnCancellableEventArgsDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDescriptionMetadata;
}(Base));
export { WebPinColumnCancellableEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPinColumnCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinColumnCancellableEventArgsDetailDescriptionMetadata } from "./WebPinColumnCancellableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDescription } from "./WebPinColumnCancellableEventArgsDescription";
/**
 * @hidden
 */
var WebPinColumnCancellableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPinColumnCancellableEventArgsDescriptionMetadata, _super);
    function WebPinColumnCancellableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnCancellableEventArgsDescriptionMetadata.b = function (a) {
        if (WebPinColumnCancellableEventArgsDescriptionMetadata.a == null) {
            WebPinColumnCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnCancellableEventArgsDescriptionMetadata.c(WebPinColumnCancellableEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPinColumnCancellableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPinColumnCancellableEventArgsDescriptionMetadata.a);
        WebPinColumnCancellableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPinColumnCancellableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPinColumnCancellableEventArgsDetail");
    };
    WebPinColumnCancellableEventArgsDescriptionMetadata.d = function (a) {
        WebPinColumnCancellableEventArgsDescriptionMetadata.b(a);
        a.ac("WebPinColumnCancellableEventArgs", function () { return new WebPinColumnCancellableEventArgsDescription(); });
        a.ab("WebPinColumnCancellableEventArgs", WebPinColumnCancellableEventArgsDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDescriptionMetadata.$t = markType(WebPinColumnCancellableEventArgsDescriptionMetadata, 'WebPinColumnCancellableEventArgsDescriptionMetadata');
    WebPinColumnCancellableEventArgsDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDescriptionMetadata;
}(Base));
export { WebPinColumnCancellableEventArgsDescriptionMetadata };
